package jfftw.demo;
import jfftw.*;

/**     Simple test program to form sin function in ComplexDataArray, 
 *      take it FFT twice and compare with the original. 
 *      Output is single text; no graphics used.
 *      @author Will Hossack, The University of Edinburgh 
 *
 */
public class OneDimensionDemo extends Object {
    public static void main(String args[]) {

	//           Basic sanity check
	if (args.length < 1) {
	    System.out.println("Usage: java OneDimensionTest length");
	    System.exit(1);
	}
	
	//           Read length from command line
	int n = Integer.parseInt(args[0]);
	double freq = 0.1;

	//           Make a one diemsnional complex signal of
	//           required length
	ComplexDataArray signal = new ComplexDataArray(n);

	//            Fill signal with complex signal of form
	//            [0.5 + sin(theta) , cos(2*theta)]

	for(int i = 0; i < signal.getWidth(); i++) {
	    double theta = 2.0*Math.PI*freq*i;
	    signal.setComplex(i,0.5 + Math.sin(theta),Math.cos(2.0*theta));
	}

	System.out.println(signal);         // Information

	//            Make clone of signal as reference (also complex)
	ComplexDataArray reference = signal.clone();

	//            Take forward FFT of signal
	signal.fourier();

	System.out.println(signal);        // Information
	
	//            Take second fouier (so form inverse)
	signal.fourier();

	System.out.println(signal);        // Information

	//         Form modulus squared difference between signal/reference
	//         should be zero (or very close)
	double diff = 0.0;

	for(int i = 0; i < signal.getWidth(); i++) {
	    
	    //        Get signal - reference (as a Complex)
	    Complex d = signal.getComplex(i).minus(reference.getComplex(i));

	    //        Take sum of modulus squared
	    diff += d.modulusSq();
	}

	System.out.println("Absolute modulus squared difference is : " + diff);

    }
}